@@ -507,12 +507,28 @@ static int smtp_get_effective_tls_level(DSN_BUF *why, SMTP_STATE *state)
     SMTP_ITERATOR *iter = state->iterator;
     SMTP_TLS_POLICY *tls = state->tls;
 
+    /*
+     * Prepare TLS feature status logging.
+     */
+    if (state->tls_stats) {
+	pol_stats_revert(state->tls_stats);
+	if (state->reqtls_level > SMTP_REQTLS_POLICY_ACT_DISABLE)
+	    smtp_tls_stat_activate_reqtls(state->tls_stats,
+					  SMTP_TLS_STAT_NAME_REQTLS,
+					  POL_STAT_ENF_FULL);
+    }
+
     /*
      * Determine the TLS level for this destination.
      */
     if (!smtp_tls_policy_cache_query(why, tls, iter)) {
+	if (state->tls_stats)
+	    smtp_tls_stat_activate_sec_unknown(state->tls_stats);
 	return (0);
     }
+    if (state->tls_stats)
+	smtp_tls_stat_activate_sec_level(state->tls_stats,
+					 state->tls->level);
 
     /*
      * Skip this destination if its TLS policy cannot satisfy the REQUIRETLS
@@ -551,11 +567,10 @@ static int smtp_get_effective_tls_level(DSN_BUF *why, SMTP_STATE *state)
 		       STR(iter->host));
 	    return (0);
 	} else if (TLS_MUST_MATCH(tls->level) == 0) {
-	    msg_info("%s: REQUIRETLS Debug: sender requested "
-		     "REQUIRETLS, but my configured TLS security "
-		     "level '%s' disables certificate matching. "
-		     "The last attempted server was %s",
-		     state->request->queue_id,
+	    msg_info("%s: Sender requested REQUIRETLS, but my "
+		     "configured TLS security level '%s' disables "
+		     "certificate matching. The last attempted server "
+		     "was %s", state->request->queue_id,
 		     str_tls_level(tls->level), STR(iter->host));
 	}
 	break;
@@ -648,19 +663,8 @@ static void smtp_connect_local(SMTP_STATE *state, const char *path)
     if (!smtp_get_effective_tls_level(why, state)) {
 	msg_warn("TLS policy lookup error for %s/%s: %s",
 		 STR(iter->host), STR(iter->addr), STR(why->reason));
-	pol_stats_revert(state->tls_stats);
-	smtp_tls_stat_activate_sec_unknown(state->tls_stats);
 	return;
     }
-    if (state->tls_stats) {
-	pol_stats_revert(state->tls_stats);
-	smtp_tls_stat_activate_sec_level(state->tls_stats,
-					 state->tls->level);
-	if (state->reqtls_level > SMTP_REQTLS_POLICY_ACT_DISABLE)
-	    smtp_tls_stat_activate_reqtls(state->tls_stats,
-					  SMTP_TLS_STAT_NAME_REQTLS,
-					  POL_STAT_ENF_FULL);
-    }
 #endif
     if ((state->misc_flags & SMTP_MISC_FLAG_CONN_LOAD) == 0
 	|| (session = smtp_reuse_nexthop(state,
@@ -1191,8 +1195,6 @@ static void smtp_connect_inet(SMTP_STATE *state, const char *nexthop,
 	    if (!smtp_get_effective_tls_level(why, state)) {
 		msg_warn("TLS policy lookup for %s/%s: %s",
 			 STR(iter->dest), STR(iter->host), STR(why->reason));
-		pol_stats_revert(state->tls_stats);
-		smtp_tls_stat_activate_sec_unknown(state->tls_stats);
 		continue;
 		/* XXX Assume there is no code at the end of this loop. */
 	    }
@@ -1208,15 +1210,6 @@ static void smtp_connect_inet(SMTP_STATE *state, const char *nexthop,
 		continue;
 		/* XXX Assume there is no code at the end of this loop. */
 	    }
-	    if (state->tls_stats) {
-		pol_stats_revert(state->tls_stats);
-		smtp_tls_stat_activate_sec_level(state->tls_stats,
-						 state->tls->level);
-		if (state->reqtls_level > SMTP_REQTLS_POLICY_ACT_DISABLE)
-		    smtp_tls_stat_activate_reqtls(state->tls_stats,
-						  SMTP_TLS_STAT_NAME_REQTLS,
-						  POL_STAT_ENF_FULL);
-	    }
 
 	    /*
 	     * Disable TLS when retrying after a handshake failure. This must
